#
# spec file for package libax25
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define         sover 0
%define src_ver 0.0.12-rc5
Name:           libax25
Version:        0.0.12~rc5
Release:        bp155.2.16
Summary:        AX.25 data link layer protocol library
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            http://www.linux-ax25.org/wiki/LinuxAX25
Source:         http://www.linux-ax25.org/pub/libax25/libax25-%{src_ver}.tar.gz
BuildRequires:  libtool
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  zlib-devel

%description
Libraries for AX.25. AX.25 (Amateur X.25) is a data link layer
protocol derived from the X.25 protocol suite and designed for use by
amateur radio operators.

%package common
Summary:        Common files for %{name}
Group:          System/Libraries
BuildArch:      noarch

%description common
Libraries for AX.25. AX.25 (Amateur X.25) is a data link layer
protocol derived from the X.25 protocol suite and designed for use by
amateur radio operators.

This package contains common config files for %{name}.

%package -n libax25-%{sover}
Summary:        AX.25 data link layer protocol library
Group:          System/Libraries
Requires:       %{name}-common

%description -n libax25-%{sover}
Libraries for AX.25. AX.25 (Amateur X.25) is a data link layer
protocol derived from the X.25 protocol suite and designed for use by
amateur radio operators.

%package -n libax25io%{sover}
Summary:        AX.25 data link layer protocol library
Group:          System/Libraries
Requires:       %{name}-common

%description -n libax25io%{sover}
Libraries for AX.25. AX.25 (Amateur X.25) is a data link layer
protocol derived from the X.25 protocol suite and designed for use by
amateur radio operators.

%package devel
Summary:        Header files for the AX.25 library
Group:          Development/Libraries/C and C++
Requires:       libax25-%{sover} = %{version}
Requires:       libax25io%{sover} = %{version}

%description devel
Header files for libax25. Used to build packages that are
linked against kernel ax25.

%prep
%setup -q -n %{name}-%{src_ver}

%build
autoreconf -fiv
%configure \
  --disable-static
%make_build

%install
%make_install installconf
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n libax25-%{sover} -p /sbin/ldconfig
%post   -n libax25io%{sover} -p /sbin/ldconfig
%postun -n libax25-%{sover} -p /sbin/ldconfig
%postun -n libax25io%{sover} -p /sbin/ldconfig

%files common
%license COPYING
%dir %{_sysconfdir}/ax25
%config %{_sysconfdir}/ax25/axports
%config %{_sysconfdir}/ax25/nrports
%config %{_sysconfdir}/ax25/rsports
%{_mandir}/man5/axports.5%{ext_man}
%{_mandir}/man5/nrports.5%{ext_man}
%{_mandir}/man5/rsports.5%{ext_man}

%files -n libax25-%{sover}
%{_libdir}/libax25.so.%{sover}*

%files -n libax25io%{sover}
%{_libdir}/libax25io.so.%{sover}*

%files devel
%doc AUTHORS ChangeLog README
%{_libdir}/libax25io.so
%{_libdir}/libax25.so
%{_includedir}/netax25
%{_mandir}/man3/ax25.3%{ext_man}
%{_mandir}/man3/rose.3%{ext_man}

%changelog
* Thu Jun  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.0.12rc5
  * Lots of stylistic cleanups to the code trying to follow the
    coding style of the kernel.
  * Lots of small cleanup and fixes to silence warnings and issues
  * Build system related changes
* Thu Jun 29 2017 mpluskal@suse.com
- Update licensing information
* Wed Jun 28 2017 jengelh@inai.de
- Make libax25-common noarch
* Tue Jun 20 2017 mpluskal@suse.com
- Update to version 0.0.12~rc4.22:
  * Ignore "compile" file.
  * Modernize daemon_start(3).
  * Package /etc/ax25/{ax,nr,rs}ports into libax25 package.
  * Add libax25-static package for statically linked applications.
  * Don't package AUTHORS, ChangeLog, COPYING, README with libax25-devel.
  * RPM: Include /etc/ax25 dir into package.
  * Update ChangeLog.
  * RPM: Build static lib package only if --enable_static was enabled.
  * Signed-off-by: Thomas Osterried <ax25@x-berg.in-berlin.de>
  * daemon.c: Fix spelling mistake initialiaze -> initialize.
- Packaging cleanups
- Split library packages and move configuration files to common
  subpackage
* Tue May  9 2017 jengelh@inai.de
- Implement shared library policy, drop static libraries.
- Use a _service file to provide a trace how the tarball was
  generated.
* Fri May  5 2017 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
* Tue May 10 2016 dl8fcl@t-online.de
- update to version 0.0.12rc4_21
* Mon Jul 13 2015 dl8fcl@darc.de
- update to version 0.0.12rc4_20
* Tue Feb 19 2013 dl8fcl@darc.de
- update to 0.0.12rc2cvs20130219
  Fixed Bug: libax25 cannot find interfaces with callsign's without SSID
* Mon Jan 21 2013 dl8fcl@darc.de
- Fix for 12.3, cleanup of spec file, changelog moved to seperate file
* Thu Jun  7 2012 dl8fcl@darc.de
- BuildRequires fixed for 12.2
* Sat Nov 14 2009 dg7gt@gmx.de
- Update to rc2 for openSUSE 11.2 (11.0 and 11.1 unchanged due to build errors)
* Fri Apr 10 2009 dg7gt@online.de
- Update to current CVS with some bug fixes
* Sun Feb  8 2009 dg7gt@online.de
- Recompiling using actual CVS version
* Sat Nov 15 2008 dg7gt@online.de
- recompiled with actual cvs version
- added devel package
* Fri Oct 24 2008 dg7gt@online.de
- recompiled with actual cvs version
* Tue Feb 20 2007 dg7gt@online.de
- imported to openSUSE Buildservice
* Sun Dec 10 2006 dg7gt@online.de
- updated version to 0.0.11
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 10 2004 adrian@suse.de
- add %%%%run_ldconfig
* Thu Dec  5 2002 jreuter@suse.de
- upgrade to version 0.0.10
- bziped source archive
* Wed Sep 18 2002 ro@suse.de
- removed bogus self-provides
* Tue Jul  2 2002 meissner@suse.de
- Cleaned up .spec, buildrooted, auto* rerun.
* Tue Feb 12 2002 jreuter@suse.de
- update to version 0.0.9
* Thu Nov 30 2000 jreuter@suse.de
- changed group to Applications/Hamradio
* Wed Nov  8 2000 sim@suse.de
- changed group to Applications/Communications
* Thu May 25 2000 sim@suse.de
- doc to /usr/share/doc
* Thu Mar  2 2000 kukuk@suse.de
- Use _mandir macro
* Thu Oct 28 1999 ka@suse.de
- added make installconf to install section of spec file
* Thu Sep 16 1999 ka@suse.de
- update to version 0.0.7
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Aug 12 1999 ka@suse.de
- more detailed configure call to fix wrong paths in ax25tool/ax25apps
* Mon Jul 19 1999 ka@suse.de
- update to version 0.0.6
* Tue Jul 13 1999 ka@suse.de
- update to version 0.0.5
- fixed typo in pathnames.h
* Fri Jun 11 1999 ka@suse.de
- added header files for glibc 2.1 received from Tomi Manninen
* Wed May 19 1999 ro@suse.de
- re-added patch to apps/call.c
* Tue May 18 1999 ka@suse.de
- added patch for procutils.c
* Fri May  7 1999 ka@suse.de
- initial release of new sources for kernel 2.2.x
- renamed package to libax25
* Tue May  4 1999 ro@suse.de
- rebuilt diff
- patched to build with glibc-2.1 and on alpha
- rspfd can't work on alpha yet due to inline asm
* Mon Mar 15 1999 ro@suse.de
- renamed subpackage to ax25dev
* Fri Mar 12 1999 ka@suse.de
- added sample configuration files to /etc/ax25/
* Thu Mar 11 1999 ka@suse.de
- initial release
